@@ -1,24 +1,10 @@
 # -*- coding: utf-8 -*-
 import os
-import numpy as np
-import random
 import torch
 from os.path import isfile
 
 
-__version__ = '0.1.2'
-
-
-def set_all(seed, n_gpu=1):
-    os.environ['PYTHONHASHSEED'] = str(seed)
-    random.seed(seed)
-    np.random.seed(seed)
-    torch.manual_seed(seed)
-    if n_gpu > 0:
-        torch.cuda.manual_seed(seed)
-        torch.cuda.manual_seed_all(seed)
-    torch.backends.cudnn.deterministic = True
-    torch.backends.cudnn.benchmark = True
+__version__ = '0.1.7'
 
 
 def tensor2list(tensor):
@@ -49,7 +35,7 @@ def load(model, ckpt_path):
         state_dict = torch.load(ckpt_path)
         new_state_dict = OrderedDict()
         for k, v in state_dict.items():
-            name = k[7:] if name.startswith('module.') else k
+            name = k.replace('module.', '')
             new_state_dict[name] = v
         model.load_state_dict(new_state_dict)
     return model
\ No newline at end of file
