@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 """ ai.helper """
 import argparse
+import bz2
 import os
 import re
 import time
@@ -37,12 +38,6 @@ class Error(Exception):
         return repr(self.value)
 
 
-class StringPatternError(Error):
-    """ Exception raised for errors in the pattern of string args.
-    """
-    pass
-
-
 class JsonEncoder(json.JSONEncoder):
     """ JsonEncoder
         解决 json.dumps 不能序列化 datetime 类型的问题：使用 Python 自带的 json.dumps 方法
@@ -66,6 +61,20 @@ def ensure_dir(path):
         os.makedirs(path)
 
 
+def ensure_dirs(dir_list):
+    """ 确保目录存在 """
+    for d in dir_list:
+        ensure_dir(d)
+
+
+def unpack_bz2(src_path):
+    data = bz2.BZ2File(src_path).read()
+    dst_path = src_path[:-4]
+    with open(dst_path, 'wb') as fp:
+        fp.write(data)
+    return dst_path
+
+
 def init_logger(log_name, log_dir):
     """ 日志模块
         1. 同时将日志打印到屏幕和文件中
@@ -377,7 +386,7 @@ def get_timestamp(s=None, style='%Y-%m-%d %H:%M:%S', pattern='s'):
         try:
             return int(time.mktime(time.strptime(s, style)) * w[pattern])
         except:
-            raise StringPatternError(" The style must be '%Y-%m-%d %H:%M:%S'\
+            raise Error("The style must be '%Y-%m-%d %H:%M:%S'\
                 or coincide with your custom format.")
     else:
         return int(time.time() * w[pattern])
@@ -478,10 +487,15 @@ def search(pattern, sequence):
     """ 从 sequence 中寻找子串 pattern
     如果找到，返回第一个下标；否则返回 -1。
     """
-    n = len(pattern)
-    for i in range(len(sequence)):
-        if sequence[i:i + n] == pattern:
-            return i
+    if isinstance(pattern, str) or isinstance(pattern, list):
+        n = len(pattern) 
+        for i in range(len(sequence)):
+            if sequence[i:i + n] == pattern:
+                return i
+    else:
+        for i in range(len(sequence)):
+            if sequence[i] == pattern:
+                return i
     return -1
 
 
@@ -490,10 +504,15 @@ def search_all(pattern, sequence):
     如果找到，返回所有起始坐标；否则返回 []。
     """
     res = []
-    n = len(pattern)
-    for i in range(len(sequence)):
-        if sequence[i:i + n] == pattern:
-            res.append([i, i+n-1])
+    if isinstance(pattern, str) or isinstance(pattern, list):
+        n = len(pattern) 
+        for i in range(len(sequence)):
+            if sequence[i:i + n] == pattern:
+                res.append(i)
+    else:
+        for i in range(len(sequence)):
+            if sequence[i] == pattern:
+                res.append(i)
     return res
 
 
