@@ -23,23 +23,25 @@ class PositionalEncoding(nn.Module):
         return self.dropout(x)
 
 
-class ResnetBlock(nn.Module):
-    def __init__(self, dim, use_bias=False):
-        super(ResnetBlock, self).__init__()
-        conv_block = []
-        conv_block += [nn.ReflectionPad2d(1),
-                       nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=use_bias),
-                       nn.InstanceNorm2d(dim),
-                       nn.ReLU(True)]
-
-        conv_block += [nn.ReflectionPad2d(1),
-                       nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=use_bias),
-                       nn.InstanceNorm2d(dim)]
-
-        self.conv_block = nn.Sequential(*conv_block)
+class Resnet(nn.Module):
+    def __init__(self, dim, bias=False):
+        super(Resnet, self).__init__()
+        conv = []
+        conv += [
+            nn.ReflectionPad2d(1),
+            nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=bias),
+            nn.InstanceNorm2d(dim),
+            nn.ReLU(True)
+        ]
+        conv += [
+            nn.ReflectionPad2d(1),
+            nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=bias),
+            nn.InstanceNorm2d(dim)
+        ]
+        self.conv = nn.Sequential(*conv)
 
     def forward(self, x):
-        out = x + self.conv_block(x)
+        out = x + self.conv(x)
         return out
 
 
@@ -64,9 +66,9 @@ class LIN(nn.Module):
         return out
 
 
-class adaLIN(nn.Module):
+class AdaLIN(nn.Module):
     def __init__(self, num_features, eps=1e-5):
-        super(adaLIN, self).__init__()
+        super(AdaLIN, self).__init__()
         self.eps = eps
         self.rho = Parameter(torch.Tensor(1, num_features, 1, 1))
         self.rho.data.fill_(0.9)
@@ -84,7 +86,7 @@ class adaLIN(nn.Module):
 class SoftAdaLIN(nn.Module):
     def __init__(self, num_features, eps=1e-5):
         super(SoftAdaLIN, self).__init__()
-        self.norm = adaLIN(num_features, eps)
+        self.norm = AdaLIN(num_features, eps)
 
         self.w_gamma = Parameter(torch.zeros(1, num_features))
         self.w_beta = Parameter(torch.zeros(1, num_features))
@@ -110,16 +112,39 @@ class SoftAdaLIN(nn.Module):
         return out
 
 
-class ResnetSoftAdaLINBlock(nn.Module):
-    def __init__(self, dim, use_bias=False):
-        super(ResnetSoftAdaLINBlock, self).__init__()
+class SE(nn.Module):
+    def __init__(self, dim):
+        super(SE, self).__init__()
+        self.fc1 = nn.Linear(dim, round(dim / 16), bias=False)
+        self.fc2 = nn.Linear(round(dim / 16), dim, bias=False)
+        self.sigmoid = nn.Sigmoid()
+        self.relu = nn.ReLU(True)
+
+    def forward(self, x):
+        x_orig = x
+
+        out = F.adaptive_avg_pool2d(x, 1)
+        out = self.fc1(out.view(out.shape[0], -1))
+        out = self.relu(out)
+        out = self.fc2(out)
+        out = self.sigmoid(out)
+        out = out.view(out.shape[0], out.shape[1], 1, 1)
+        out = out * x_orig
+
+        out += x
+        return out
+
+
+class ResnetSoftAdaLIN(nn.Module):
+    def __init__(self, dim, bias=False):
+        super(ResnetSoftAdaLIN, self).__init__()
         self.pad1 = nn.ReflectionPad2d(1)
-        self.conv1 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=use_bias)
+        self.conv1 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=bias)
         self.norm1 = SoftAdaLIN(dim)
         self.relu1 = nn.ReLU(True)
 
         self.pad2 = nn.ReflectionPad2d(1)
-        self.conv2 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=use_bias)
+        self.conv2 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=bias)
         self.norm2 = SoftAdaLIN(dim)
 
     def forward(self, x, content_features, style_features):
@@ -134,17 +159,17 @@ class ResnetSoftAdaLINBlock(nn.Module):
         return out + x
 
 
-class ResnetAdaLINBlock(nn.Module):
-    def __init__(self, dim, use_bias=False):
-        super(ResnetAdaLINBlock, self).__init__()
+class ResnetAdaLIN(nn.Module):
+    def __init__(self, dim, bias=False):
+        super(ResnetAdaLIN, self).__init__()
         self.pad1 = nn.ReflectionPad2d(1)
-        self.conv1 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=use_bias)
-        self.norm1 = adaLIN(dim)
+        self.conv1 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=bias)
+        self.norm1 = AdaLIN(dim)
         self.relu1 = nn.ReLU(True)
 
         self.pad2 = nn.ReflectionPad2d(1)
-        self.conv2 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=use_bias)
-        self.norm2 = adaLIN(dim)
+        self.conv2 = nn.Conv2d(dim, dim, kernel_size=3, stride=1, padding=0, bias=bias)
+        self.norm2 = AdaLIN(dim)
 
     def forward(self, x, gamma, beta):
         out = self.pad1(x)
