@@ -4,44 +4,15 @@ import numpy as np
 import torch
 import torch.nn as nn
 from collections import OrderedDict
-from pyecharts.charts import Bar
-from pyecharts.render import make_snapshot
-from snapshot_selenium import snapshot
 
 
-def plot_histogram(name, items, values, mode='html', img_path='res.png'):
-    """ 绘制直方图
-    Note:
-        从 pyecharts v1 版本开始，add_yaxis 需要传入两个参数，第一个参数为 str 类型
-    	关于 snapshot: snapshot-selenium 是 pyecharts + selenium 渲染图片的扩展，使用 selenium 需要配置 browser driver。
-    	可以参考 selenium-python 相关介绍，推荐使用 Chrome 浏览器，可以开启 headless 模式。目前支持 Chrome, Safari。
-    	Download: https://selenium-python.readthedocs.io/installation.html#drivers
-    	Make sure it’s in your PATH, e. g., place it in /usr/bin or /usr/local/bin.
-    """
-    bar = Bar()
-    bar.add_xaxis(items)
-    bar.add_yaxis(name, values)
-    if mode == 'html':
-        return bar.render()
-    elif mode == 'notebook':
-        return bar.render_notebook()
-    elif mode == 'img':
-        make_snapshot(snapshot, bar.render(), img_path)
-    else:
-        raise ValueError("mode must in ['html', 'notebook', 'img']")
-
-
-def summary(model, input_size, batch_size=-1, device=torch.device('cuda:0'), dtypes=None):
-    result, params_info = summary_string(model, input_size, batch_size, device, dtypes)
-    print(result)
-    return params_info
-
-
-def summary_string(model, input_size, batch_size=-1, device=torch.device('cuda:0'), dtypes=None):
+def summary(model, input_size, batch_size=1, dtypes=None):
     if dtypes == None:
         dtypes = [torch.FloatTensor] * len(input_size)
-
-    summary_str = ''
+    
+    # multiple inputs
+    if isinstance(input_size, tuple):
+        input_size = [input_size]
 
     def register_hook(module):
         def hook(module, input, output):
@@ -71,21 +42,17 @@ def summary_string(model, input_size, batch_size=-1, device=torch.device('cuda:0
         if not isinstance(module, nn.Sequential) and not isinstance(module, nn.ModuleList):
             hooks.append(module.register_forward_hook(hook))
 
-    # multiple inputs
-    if isinstance(input_size, tuple):
-        input_size = [input_size]
-
-    # batch_size of 2 for batchnorm
-    x = [torch.rand(2, *in_size).type(dtype).to(device=device)
-         for in_size, dtype in zip(input_size, dtypes)]
-
-    # create properties
+    summary_str = ''
     summary = OrderedDict()
     hooks = []
+    device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
 
     # register hook
     model.apply(register_hook)
 
+    # batch_size of 2 for batchnorm
+    x = [torch.rand(2, *in_size).type(dtype).to(device=device) for in_size, dtype in zip(input_size, dtypes)]
+
     # make a forward pass
     model(*x)
 
